
# Slot: object




URI: [biolink:transcript_to_gene_relationship_object](https://w3id.org/biolink/vocab/transcript_to_gene_relationship_object)


## Domain and Range

[TranscriptToGeneRelationship](TranscriptToGeneRelationship.md) &#8594;  <sub>1..1</sub> [Gene](Gene.md)

## Parents

 *  is_a: [sequence feature relationship➞object](sequence_feature_relationship_object.md)

## Children


## Used by

 * [TranscriptToGeneRelationship](TranscriptToGeneRelationship.md)
